@@ -1,4 +1,6 @@
-if (requireNamespace("spelling", quietly = TRUE))
+if (requireNamespace("spelling", quietly = TRUE) &&
+    requireNamespace("hunspell", quietly = TRUE)) {
   spelling::spell_check_test(vignettes = TRUE, 
                              error = TRUE,
                              skip_on_cran = TRUE)
+}
